@@ -43,10 +43,20 @@ from .events import (
     find_event_mapper_by_name,
     find_event_mapper_by_type,
 )
-from .utils import env, get_env, get_simple_logger
+from .subprocess import SubprocessResult, run_subprocess  # nosec
+from .utils import (
+    env,
+    get_bool_env,
+    get_env,
+    get_float_env,
+    get_int_env,
+    get_list_str_env,
+    get_simple_logger,
+    get_str_env,
+)
 from .value_objects import Id, StrDateTime, Timestamp
 
-__version__ = '1.3.6'
+__version__ = '1.3.8'
 
 __all__ = (
     # aggregates
@@ -92,10 +102,18 @@ __all__ = (
     'InternalEventPublisher',
     # utils
     'get_env',
+    'get_str_env',
+    'get_bool_env',
+    'get_int_env',
+    'get_float_env',
+    'get_list_str_env',
     'get_simple_logger',
     'env',
     # value_objects
     'Id',
     'Timestamp',
     'StrDateTime',
+    # subprocess,
+    'SubprocessResult',
+    'run_subprocess',
 )
